@@ -110,7 +110,7 @@ static const std::map<std::string, bool (*)(bmap_t &, const tinyxml2::XMLElement
 	{ "BlockMap", parse_block_map },
 };
 
-void send_info(std::string msg)
+void send_info(const std::string &msg)
 {
 	uuu_notify nt;
 	nt.type = uuu_notify::NOTIFY_CMD_INFO;
@@ -118,7 +118,7 @@ void send_info(std::string msg)
 	call_notify(nt);
 }
 
-bool load_bmap(const std::string& filename, bmap_t& bmap)
+int load_bmap(const std::string& filename, bmap_t& bmap)
 {
 	tinyxml2::XMLDocument doc;
 	auto fbuf = get_file_buffer(filename, true);
@@ -174,5 +174,5 @@ bool load_bmap(const std::string& filename, bmap_t& bmap)
 		send_info(info + "\n");
 	}
 
-	return true;
+	return 0;
 }
